﻿#!/usr/bin/env python3
# -*- coding:utf-8 -*-
#-------------------------------------------------------------------------------
# Name:        RinexPicker
# Purpose:      時刻と時間幅を記載したファイルに基づき、RINEXファイルを分割します。
#               現時点での用途としては、静止中の観測データのみを切り出せるかなぁといったとことです。
#               （ただし、この場合は時刻のリストを他の手段で作る必要がある。）
#
# Author:      morishita
#
# Created:     04/01/2013
# Copyright:   (c) morishita 2013
# Licence:     new BSD
# History:     2013/3/30 古いファイルで上書きしてしまっていたので修正した。
#-------------------------------------------------------------------------------
#!/usr/bin/env python

import os
import sys
import re
import datetime
import RINEXm
import timeKM

def main():
    """ 第一引数がRINEX観測ファイル、第二引数が時間のリスト
    """
    argvs = sys.argv  # コマンドライン引数を格納したリストの取得
    argc = len(argvs) # 引数の個数
    # デバッグプリント
    print(argvs)
    print(argc)
    #print
    if (argc != 3):                                     # 引数が足りない場合は、その旨を表示
        print('Usage: # python %s filename' % argvs[0]) # 0はスクリプトファイル自体を指す
        quit()                                          # プログラムの終了
    fnameOfRinex    = argvs[1]
    if RINEXm.isRINEX(fnameOfRinex) == False:           # RINEXファイルでなければ終了
        print("{0} is not RINEX file.".format(fnameOfRinex))
        print("program fin.")
        quit()
    fnameOfTimeList = argvs[2]
    if os.path.exists(fnameOfTimeList) == False:        # ファイルの存在が確認できない場合は終了
        quit()
    if os.path.isfile(fnameOfTimeList) != True:         # ファイルでなければ終了
        quit()
    # タイムリスト読み込み
    fr = open(fnameOfTimeList,"r")
    lines = fr.readlines()
    fr.close()
    if len(lines) == 0:
        quit()
    # RTKLIBのログファイル読み込み
    _rinex = RINEXm.RINEX(fnameOfRinex)
    if _rinex == None:
        print("program fin.")
        quit()
    root, ext = os.path.splitext(fnameOfRinex)          # ファイル名と拡張子に分ける。拡張子には.が入っている
    fnameOfRinex_name = os.path.basename(root)
    # 日付および時間幅(正確には数値なら何でも合致するのだが)に一致する正規表現モジュール
    # [yyyy/MM/dd hh:mm:ss]または[yyyy-MM-dd hh:mm:ss]にヒットする。(/|-)で、/か-で区切られた日付にヒットする。
    listPattern = re.compile(r'(?P<date>(?P<year>\d{4})(?:/|-)(?P<month>\d{1,2})(?:/|-)(?P<day>\d{1,2}))\ (?P<clock>(?P<hour>\d{1,2}):(?P<minute>\d{1,2}):(?P<second>\d{1,2}[.]?\d*))(,|\t)(?P<timeWidth>\d+)')
    index = 0
    for line in lines:
        print("index: {0}/{1}".format(index + 1, len(lines)))
        matchTest = listPattern.search(line)
        if matchTest != None:
            time = timeKM.getTime(line)
            tw   = int(matchTest.group('timeWidth'))
            t1 = time
            t2 = time + datetime.timedelta(seconds=tw)
            print("now: {0} to {1}".format(t1, t2))
            fname = "{0} picked_rinex_{1:03}{2}".format(fnameOfRinex_name, index, ext)
            __rinex = _rinex.pickOut(t1, t2)
            __rinex.save(fname)
        index += 1
    return

if __name__ == '__main__':
    main()
